pecos.qeclib.qubit.sq\_face\_rots
=================================

.. automodule:: pecos.qeclib.qubit.sq_face_rots











   .. rubric:: Classes

   .. autosummary::

      F
      F4
      F4dg
      Fdg
